@@ -21,8 +21,19 @@
 #include "config.h"
 
 #define _GNU_SOURCE
+
+/* We want to build the fork-based version, not the threaded version. */
 #undef HAVE_PTHREAD
 
+/* For old OS X, #580301. Remove if these are added to asyncns.c
+ * in the future.
+ */
+#include <sys/time.h>
+#include <stdint.h>
+
+/* Some BSDs require this for getrlimit */
+#include <sys/resource.h>
+
 #include "asyncns.h"
 
 #endif
